@@ -131,6 +131,8 @@ class EvaluationView(QtWidgets.QWidget):
         session = Session.get_instance()
         evm = session.evaluation_model()
         if evm is None:
+            self.bounds_table.setRowCount(0)
+            self.bounds_table.setEnabled(False)
             return
         bounds = evm.bounds
         if bounds is None:
@@ -222,32 +224,34 @@ class EvaluationView(QtWidgets.QWidget):
         # Get spectrum and plot it
         self.isd_spectrum_plot.cla()
         spectra = session.evaluation_model().get_spectra(image_key)
-        if spectra is not None:
+        cm = session.calibration_model()
+        payload_time = session.get_payload_time(image_key)
+        frequencies = cm.get_frequencies_by_time(payload_time)
+
+        if spectra is not None and frequencies is not None:
             image_nr = 0
             spectrum = np.nanmean(spectra, image_nr)
 
             # Also try to get the fit
             brillouin_fits, rayleigh_fits =\
                 self.evaluation_controller.get_fits(image_key)
-            x = range(len(spectrum))
+
+            # Show the measured data
+            self.isd_spectrum_plot.plot(1e-9 * frequencies[0],
+                                        spectrum, color='tab:blue')
+            self.isd_spectrum_plot.set_xlabel('$f$ [GHz]')
 
             pm = session.peak_selection_model()
             evm = session.evaluation_model()
             if pm is not None and evm is not None:
-                shift = np.nanmean(
-                    evm.results['rayleigh_shift'][
-                        indices[0], indices[1], indices[2], :, :, :]
-                )
-                if np.isnan(shift):
-                    shift = 0
-
                 # Show the Brillouin peaks
                 brillouin_regions = pm.get_brillouin_regions()
                 # Iterate over the regions
                 for region_nr in range(brillouin_fits[0].shape[1]):
-                    x = range(
-                        brillouin_regions[region_nr][0] + round(shift),
-                        brillouin_regions[region_nr][1] + round(shift)
+                    x = np.linspace(
+                        brillouin_regions[region_nr][0],
+                        brillouin_regions[region_nr][1],
+                        200
                     )
                     # Iterate over the multi-fit peaks
                     for peak_nr in range(brillouin_fits[0].shape[2]):
@@ -262,15 +266,16 @@ class EvaluationView(QtWidgets.QWidget):
                             color = 'tab:orange'
                         else:
                             color = 'tab:red'
-                        self.isd_spectrum_plot.plot(x, y, color=color)
+                        self.isd_spectrum_plot.plot(1e-9 * x, y, color=color)
 
                 # Show the Rayleigh peaks
                 rayleigh_regions = pm.get_rayleigh_regions()
                 # Iterate over the regions
                 for region_nr in range(rayleigh_fits[0].shape[1]):
-                    x = range(
-                        rayleigh_regions[region_nr][0] + round(shift),
-                        rayleigh_regions[region_nr][1] + round(shift)
+                    x = np.linspace(
+                        rayleigh_regions[region_nr][0],
+                        rayleigh_regions[region_nr][1],
+                        200
                     )
                     idx = (image_nr, region_nr, 0)
                     y = lorentz(
@@ -279,10 +284,8 @@ class EvaluationView(QtWidgets.QWidget):
                         rayleigh_fits[1][idx],
                         rayleigh_fits[2][idx]
                     ) + rayleigh_fits[3][idx]
-                    self.isd_spectrum_plot.plot(x, y, color='tab:purple')
-
-            # Show the measured data
-            self.isd_spectrum_plot.plot(spectrum, color='tab:blue')
+                    self.isd_spectrum_plot.plot(1e-9 * x,
+                                                y, color='tab:purple')
 
         self.isd_spectrum_canvas.draw()
 
@@ -360,6 +363,10 @@ class EvaluationView(QtWidgets.QWidget):
         self.evaluation_progress.setValue(0)
         self.clear_plots()
         self.plot.cla()
+        self.updateBoundsTable()
+        self.nrBrillouinPeaks_1.setChecked(True)
+        self.combobox_parameter.clear()
+        self.combobox_peak_number.setEnabled(False)
 
         self.mplcanvas.draw()
 
@@ -555,31 +562,14 @@ class EvaluationView(QtWidgets.QWidget):
                         action='ignore',
                         message='All-NaN slice encountered'
                     )
-                    if self.autoscale.isChecked():
-                        value_min = np.nanmin(data)
-                        value_max = np.nanmax(data)
-                        self.value_min.blockSignals(True)
-                        self.value_min.setValue(value_min)
-                        self.value_min.blockSignals(False)
-                        self.value_max.blockSignals(True)
-                        self.value_max.setValue(value_max)
-                        self.value_max.blockSignals(False)
-                    else:
-                        value_min = self.value_min.value()
-                        value_max = self.value_max.value()
-                    if value_min > value_max:
-                        value_min = np.nanmin(data)
-                        value_max = np.nanmax(data)
-                    # Adjust the double spin box step size
-                    single_step = (value_max - value_min)/15
-                    self.value_min.setSingleStep(single_step)
-                    self.value_max.setSingleStep(single_step)
-                    self.plot.set_ylim(
-                        value_min,
-                        value_max
-                    )
+                    (value_min, value_max) = self.get_plot_limits(data)
+                    if value_min < value_max:
+                        self.plot.set_ylim(
+                            value_min,
+                            value_max
+                        )
             if dimensionality == 2:
-                # We rotate the array so the x axis is shown as the
+                # We rotate the array so the x-axis is shown as the
                 # horizontal axis
                 image_map = data[tuple(dslice)]
                 image_map = np.rot90(image_map)
@@ -604,23 +594,8 @@ class EvaluationView(QtWidgets.QWidget):
                         action='ignore',
                         message='All-NaN slice encountered'
                     )
-                    if self.autoscale.isChecked():
-                        value_min = np.nanmin(data[tuple(dslice)])
-                        value_max = np.nanmax(data[tuple(dslice)])
-                        self.value_min.blockSignals(True)
-                        self.value_min.setValue(value_min)
-                        self.value_min.blockSignals(False)
-                        self.value_max.blockSignals(True)
-                        self.value_max.setValue(value_max)
-                        self.value_max.blockSignals(False)
-                    else:
-                        value_min = self.value_min.value()
-                        value_max = self.value_max.value()
+                    (value_min, value_max) = self.get_plot_limits(data)
                     if value_min < value_max:
-                        # Adjust the double spin box step size
-                        single_step = (value_max - value_min)/15
-                        self.value_min.setSingleStep(single_step)
-                        self.value_max.setSingleStep(single_step)
                         self.image_map.set_clim(value_min, value_max)
                         # For some reason we have to apply the color limits
                         # twice to make it work properly
@@ -644,25 +619,7 @@ class EvaluationView(QtWidgets.QWidget):
                     np.nanmax(positions[idx[1]][tuple(dslice)])
                 )
             if dimensionality == 3:
-                if self.autoscale.isChecked():
-                    value_min = np.nanmin(data)
-                    value_max = np.nanmax(data)
-                    self.value_min.blockSignals(True)
-                    self.value_min.setValue(value_min)
-                    self.value_min.blockSignals(False)
-                    self.value_max.blockSignals(True)
-                    self.value_max.setValue(value_max)
-                    self.value_max.blockSignals(False)
-                else:
-                    value_min = self.value_min.value()
-                    value_max = self.value_max.value()
-                    if value_min > value_max:
-                        value_min = np.nanmin(data)
-                        value_max = np.nanmax(data)
-                # Adjust the double spin box step size
-                single_step = (value_max - value_min)/15
-                self.value_min.setSingleStep(single_step)
-                self.value_max.setSingleStep(single_step)
+                (value_min, value_max) = self.get_plot_limits(data)
 
                 scalar_map = matplotlib.cm.ScalarMappable(
                     norm=Normalize(vmin=value_min, vmax=value_max),
@@ -703,3 +660,27 @@ class EvaluationView(QtWidgets.QWidget):
         except Exception:
             self.reset_ui()
             pass
+
+    def get_plot_limits(self, data):
+        if self.autoscale.isChecked():
+            value_min = np.nanmin(data)
+            value_max = np.nanmax(data)
+            self.value_min.blockSignals(True)
+            self.value_min.setValue(value_min)
+            self.value_min.blockSignals(False)
+            self.value_max.blockSignals(True)
+            self.value_max.setValue(value_max)
+            self.value_max.blockSignals(False)
+        else:
+            value_min = self.value_min.value()
+            value_max = self.value_max.value()
+            if value_min > value_max:
+                value_min = np.nanmin(data)
+                value_max = np.nanmax(data)
+        if value_min < value_max:
+            # Adjust the double spin box step size
+            single_step = (value_max - value_min) / 15
+            self.value_min.setSingleStep(single_step)
+            self.value_max.setSingleStep(single_step)
+
+        return value_min, value_max
